@@ -23,15 +23,17 @@ class Dplay(Service):
         data = self.get_urldata()
         premium = False
         parse = urlparse(self.url)
-        domain = re.search("(dplay\.\w\w)", parse.netloc).group(1)
+        domain = re.search(r"(dplay\.\w\w)", parse.netloc).group(1)
         if self.exclude(self.options):
             yield ServiceError("Excluding video")
             return
 
-        match = re.search("<link rel='shortlink' href='[^']+/\?p=(\d+)", data)
+        match = re.search(r"<link rel='shortlink' href='[^']+/\?p=(\d+)", data)
         if not match:
-            yield ServiceError("Can't find video id")
-            return
+            match = re.search(r'data-video-id="([^"]+)"', data)
+            if not match:
+                yield ServiceError("Can't find video id")
+                return
         vid = match.group(1)
         data = self.http.request("get", "http://%s/api/v2/ajax/videos?video_id=%s" % (parse.netloc, vid)).text
         dataj = json.loads(data)
@@ -81,7 +83,7 @@ class Dplay(Service):
         else:
             self.options.cookies = cookie
         data = self.http.request("get", "https://secure.%s/secure/api/v2/user/authorization/stream/%s?stream_type=hds" % (domain, vid), cookies=self.options.cookies)
-        if data.status_code == 403:
+        if data.status_code == 403 or data.status_code == 401:
             yield ServiceError("Geoblocked video")
             return
         dataj = json.loads(data.text)
@@ -107,7 +109,7 @@ class Dplay(Service):
 
     def _login(self, options):
         parse = urlparse(self.url)
-        domain = re.search("(dplay\.\w\w)", parse.netloc).group(1)
+        domain = re.search(r"(dplay\.\w\w)", parse.netloc).group(1)
         data = self.http.request("get", "https://secure.%s/login/" % domain, cookies={})
         options.cookies = data.cookies
         match = re.search('realm_code" value="([^"]+)"', data.text)
@@ -133,7 +135,7 @@ class Dplay(Service):
     def find_all_episodes(self, options):
         data = self.get_urldata()
         parse = urlparse(self.url)
-        domain = re.search("(dplay\.\w\w)", parse.netloc).group(1)
+        domain = re.search(r"(dplay\.\w\w)", parse.netloc).group(1)
         match = re.search('data-show-id="([^"]+)"', data)
         if not match:
             log.error("Cant find show id")
