@@ -9,10 +9,11 @@ import hashlib
 
 from svtplay_dl.log import log
 from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.utils import filenamify, ensure_unicode, is_py2
-from svtplay_dl.utils.urllib import urlparse, urljoin
+from svtplay_dl.utils import filenamify, ensure_unicode, is_py2, decode_html_entities
+from svtplay_dl.utils.urllib import urlparse, urljoin, parse_qs
 from svtplay_dl.fetcher.hds import hdsparse
 from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.fetcher.dash import dashparse
 from svtplay_dl.subtitle import subtitle
 from svtplay_dl.error import ServiceError
 
@@ -25,7 +26,7 @@ class Svtplay(Service, OpenGraphThumbMixin):
 
         parse = urlparse(self.url)
         if parse.netloc == "www.svtplay.se" or parse.netloc == "svtplay.se":
-            if parse.path[:6] != "/video":
+            if parse.path[:6] != "/video" and parse.path[:6] != "/klipp":
                 yield ServiceError("This mode is not supported anymore. need the url with the video")
                 return
 
@@ -47,7 +48,11 @@ class Svtplay(Service, OpenGraphThumbMixin):
             self.options.live = data["live"]
         if old:
             params = {"output": "json"}
-            dataj = self.http.request("get", self.url, params=params).json()
+            try:
+                dataj = self.http.request("get", self.url, params=params).json()
+            except ValueError:
+                dataj = data
+                old = False
         else:
             dataj = data
 
@@ -91,21 +96,60 @@ class Svtplay(Service, OpenGraphThumbMixin):
                     if streams:
                         for n in list(streams.keys()):
                             yield streams[n]
+            if i["format"] == "dash264":
+                streams = dashparse(self.options, self.http.request("get", i["url"]), i["url"])
+                if streams:
+                    for n in list(streams.keys()):
+                        yield streams[n]
+
 
     def find_video_id(self):
         match = re.search('data-video-id="([^"]+)"', self.get_urldata())
         if match:
             return match.group(1)
         parse = urlparse(self.url)
+        query = parse_qs(parse.query)
         match = re.search("/video/([0-9]+)/", parse.path)
         if match:
             return match.group(1)
-        match = re.search("/videoEpisod-([^/]+)/", parse.path)
+        match = re.search("/klipp/([0-9]+)/", parse.path)
         if match:
-            self._urldata = None
-            self._url = "http://www.svtplay.se/video/%s/" % match.group(1)
-            self.get_urldata()
-            return self.find_video_id()
+            return match.group(1)
+        match = re.search("data-video-id='([^']+)'", self.get_urldata())
+        if match:
+            return match.group(1)
+        match = re.search("/videoEpisod-([^/]+)/", parse.path)
+        if not match:
+            match = re.search(r'data-id="(\d+)-', self.get_urldata())
+        vid = None
+        if match:
+            vid = match.group(1)
+        if not vid:
+            for i in query.keys():
+                if i == "articleId":
+                    vid = query["articleId"][0]
+                    break
+        if vid:
+            vtype = None
+            for i in ["video", "klipp"]:
+                url = "http://www.svtplay.se/%s/%s/" % (i, vid)
+                data = self.http.request("get", url)
+                if data.status_code == 200:
+                    vtype = i
+                    break
+            if vtype:
+                self._url = "http://www.svtplay.se/%s/%s/" % (vtype, vid)
+                self._urldata = None
+                self.get_urldata()
+                return self.find_video_id()
+        if not match:
+            match = re.search(r'src="(//www.svt.se/wd?[^"]+)"', self.get_urldata())
+            if match:
+                self._urldata = None
+                self._url = "http:%s" % decode_html_entities(match.group(1))
+                self.get_urldata()
+                return self.find_video_id()
+
         return None
 
     def find_all_episodes(self, options):
@@ -146,10 +190,16 @@ class Svtplay(Service, OpenGraphThumbMixin):
             id = data["videoId"]
         else:
             name = data["programTitle"]
-            if name.find(".") > 0:
-                name = name[:name.find(".")]
-            name = filenamify(name.replace(" - ", "."))
-            other = filenamify(data["episodeTitle"])
+            if not name:
+                match = re.search('data-title="([^"]+)"', raw)
+                if match:
+                    name = filenamify(match.group(1).replace(" - ", "."))
+                other = None
+            else:
+                if name.find(".") > 0:
+                    name = name[:name.find(".")]
+                name = filenamify(name.replace(" - ", "."))
+                other = filenamify(data["episodeTitle"])
             if is_py2:
                 id = hashlib.sha256(data["programVersionId"]).hexdigest()[:7]
             else:
