@@ -11,12 +11,13 @@ import platform
 
 
 class subtitle(object):
-    def __init__(self, options, subtype, url):
+    def __init__(self, options, subtype, url, subfix = None):
         self.url = url
         self.subtitle = None
         self.options = options
         self.subtype = subtype
         self.http = Session()
+        self.subfix = subfix
 
     def download(self):
         subdata = self.http.request("get", self.url, cookies=self.options.cookies)
@@ -37,7 +38,10 @@ class subtitle(object):
                 data = subdata.text.encode("utf-8")
             else:
                 data = subdata.text
-
+        
+        if self.subfix:
+            self.options.output = self.options.output + self.subfix
+            
         if platform.system() == "Windows" and is_py3:
             file_d = output(self.options, "srt", mode="wt", encoding="utf-8")
         else:
@@ -199,7 +203,8 @@ class subtitle(object):
                 subnr = True
             else:
                 sub = re.sub('<[^>]*>', '', i)
-                srt += sub.lstrip()
+                srt += sub.strip()
+                srt+="\n"
         srt = decode_html_entities(srt)
         if is_py2:
             return srt.encode("utf-8")
